@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: e_cback.h 2454 2008-08-31 11:12:47Z mbarbon $
+// RCS-ID:      $Id: e_cback.h 3374 2012-09-26 11:37:03Z mdootson $
 // Copyright:   (c) 2000-2001, 2005, 2008 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -23,6 +23,31 @@ typedef void (wxObject::* wxPliObjectEventFunction)(wxEvent&);
     ((wxObjectEventFunction) e)
 #endif
 
+class wxPliGuard
+{
+public:
+    wxPliGuard()
+    {
+        m_sv = NULL;
+    }
+
+    ~wxPliGuard()
+    {
+        if( m_sv )
+        {
+            dTHX;
+
+            wxPli_thread_sv_unregister( aTHX_ wxPli_get_class( aTHX_ m_sv ),
+                                        (void*)SvIV( m_sv ), m_sv );
+            sv_setiv( m_sv, 0 );
+        }
+    }
+
+    void SetSV( SV* sv ) { m_sv = sv; }
+private:
+    SV* m_sv;
+};
+
 class wxPliEventCallback : public wxObject
 {
 public:
